@@ -179,7 +179,7 @@ class ChunksFormatter(Formatter):
         for node_value in arg_node.values:
             if isinstance(node_value, ast.Constant):
                 # These are the parts of the f-string not enclosed by `{}`, e.g. 'foo ' in f'foo {bar}'
-                value: str = node_value.value
+                value: str = node_value.value  # type: ignore
                 result.append({'v': value, 't': 'lit'})
                 new_template += value
             else:
@@ -336,6 +336,8 @@ def logfire_format_with_magic(
         return ''.join(chunk['v'] for chunk in chunks), extra_attrs, new_template
     except KnownFormattingError as e:
         warn_formatting(str(e) or str(e.__cause__))
+    except FStringAwaitError as e:
+        warn_fstring_await(str(e))
     except Exception:
         # This is an unexpected error that likely indicates a bug in our logic.
         # Handle it here so that the span/log still gets created, just without a nice message.
@@ -354,6 +356,12 @@ def compile_formatted_value(node: ast.FormattedValue, ex_source: executing.Sourc
     3. Another code object which formats the value.
     """
     source = get_node_source_text(node.value, ex_source)
+
+    # Check if the expression contains await before attempting to compile
+    for sub_node in ast.walk(node.value):
+        if isinstance(sub_node, ast.Await):
+            raise FStringAwaitError(source)
+
     value_code = compile(source, '<fvalue1>', 'eval')
     expr = ast.Expression(
         ast.JoinedStr(
@@ -386,7 +394,6 @@ def get_node_source_text(node: ast.AST, ex_source: executing.Source):
     This happens sometimes due to Python bugs (especially for older Python versions)
     in the source positions of AST nodes inside f-strings.
     """
-    # ast.unparse is not available in Python 3.8, which is why inspect_arguments is forbidden in 3.8.
     source_unparsed = ast.unparse(node)
     source_segment = ast.get_source_segment(ex_source.text, node) or ''
     try:
@@ -435,6 +442,14 @@ class KnownFormattingError(Exception):
     """
 
 
+class FStringAwaitError(Exception):
+    """An error raised when an await expression is found in an f-string.
+
+    This is a specific case that can't be handled by f-string introspection and requires
+    pre-evaluating the await expression before logging.
+    """
+
+
 class FormattingFailedWarning(UserWarning):
     pass
 
@@ -449,3 +464,17 @@ def warn_formatting(msg: str):
         f'    The problem was: {msg}',
         category=FormattingFailedWarning,
     )
+
+
+def warn_fstring_await(msg: str):
+    warn_at_user_stacklevel(
+        f'\n'
+        f'    Cannot evaluate await expression in f-string. Pre-evaluate the expression before logging.\n'
+        '    For example, change:\n'
+        '      logfire.info(f"{await get_value()}")\n'
+        '    To:\n'
+        '      value = await get_value()\n'
+        '      logfire.info(f"{value}")\n'
+        f'    The problematic f-string value was: {msg}',
+        category=FormattingFailedWarning,
+    )
