@@ -6,11 +6,11 @@ from unittest import mock
 
 import pytest
 import requests.exceptions
-from dirty_equals import IsStr
+from dirty_equals import IsPartialDict, IsStr
 from inline_snapshot import snapshot
 from opentelemetry._events import Event, get_event_logger, get_event_logger_provider
-from opentelemetry._logs import LogRecord, SeverityNumber, get_logger, get_logger_provider
-from opentelemetry.sdk._logs import LogData
+from opentelemetry._logs import SeverityNumber, get_logger, get_logger_provider
+from opentelemetry.sdk._logs import LogData, LogRecord
 from opentelemetry.sdk._logs.export import (
     InMemoryLogExporter,
     LogExporter,
@@ -18,10 +18,12 @@ from opentelemetry.sdk._logs.export import (
     SimpleLogRecordProcessor,
 )
 from opentelemetry.sdk.resources import Resource
+from opentelemetry.version import __version__ as otel_version
 
 import logfire
 from logfire import suppress_instrumentation
 from logfire._internal.exporters.otlp import QuietLogExporter
+from logfire._internal.utils import get_version
 from logfire.testing import TestLogExporter
 
 
@@ -29,8 +31,6 @@ def test_otel_logs_supress_scopes(logs_exporter: InMemoryLogExporter, config_kwa
     record = LogRecord(
         timestamp=1,
         observed_timestamp=2,
-        trace_id=3,
-        span_id=4,
         severity_text='INFO',
         severity_number=SeverityNumber.INFO,
         body='body',
@@ -77,16 +77,27 @@ def test_get_logger_provider() -> None:
 
 
 def test_log_events(logs_exporter: TestLogExporter) -> None:
-    logger = get_event_logger('scope')
-    record = Event(
-        name='my_event',
-        timestamp=2,
-        severity_number=SeverityNumber.INFO,
-        body='body',
-        attributes={'key': 'value'},
-    )
+    logger = get_logger('scope')
+    event_logger = get_event_logger('scope')
     with logfire.span('span'):
-        logger.emit(record)
+        if get_version(otel_version) >= get_version('1.35.0'):
+            record = LogRecord(
+                event_name='my_event',
+                timestamp=2,
+                severity_number=SeverityNumber.INFO,
+                body='body',
+                attributes={'key': 'value'},
+            )
+            logger.emit(record)
+        else:
+            event = Event(
+                name='my_event',
+                timestamp=2,
+                severity_number=SeverityNumber.INFO,
+                body='body',
+                attributes={'key': 'value'},
+            )
+            event_logger.emit(event)
 
     assert logs_exporter.exported_logs_as_dicts(include_resources=True, include_instrumentation_scope=True) == snapshot(
         [
@@ -94,7 +105,7 @@ def test_log_events(logs_exporter: TestLogExporter) -> None:
                 'body': 'body',
                 'severity_number': 9,
                 'severity_text': None,
-                'attributes': {'key': 'value', 'event.name': 'my_event'},
+                'attributes': IsPartialDict({'key': 'value'}),
                 'timestamp': 2000000000,
                 'observed_timestamp': 3000000000,
                 'trace_id': 1,
